@@ -1,9 +1,10 @@
 //! Block metadata
 
 use super::{Header, Id};
-use crate::{Error, Kind};
+use crate::error::Error;
+use crate::prelude::*;
+use core::convert::{TryFrom, TryInto};
 use serde::{Deserialize, Serialize};
-use std::convert::{TryFrom, TryInto};
 use tendermint_proto::types::BlockMeta as RawMeta;
 
 /// Block metadata - Todo: implement constructor and getters
@@ -30,12 +31,12 @@ impl TryFrom<RawMeta> for Meta {
         Ok(Meta {
             block_id: value
                 .block_id
-                .ok_or_else(|| Error::from(Kind::InvalidBlock.context("no block_id")))?
+                .ok_or_else(|| Error::invalid_block("no block_id".to_string()))?
                 .try_into()?,
             block_size: value.block_size,
             header: value
                 .header
-                .ok_or_else(|| Error::from(Kind::InvalidBlock.context("no header")))?
+                .ok_or_else(|| Error::invalid_block("no header".to_string()))?
                 .try_into()?,
             num_txs: value.num_txs,
         })
